Index: trunk/psModules/src/camera/pmHDU.h
===================================================================
--- trunk/psModules/src/camera/pmHDU.h	(revision 21279)
+++ trunk/psModules/src/camera/pmHDU.h	(revision 21363)
@@ -4,6 +4,7 @@
  * @author Paul Price, IfA
  *
- * @version $Revision: 1.10 $ $Name: not supported by cvs2svn $
- * @date $Date: 2009-02-04 02:39:36 $
+ * @version $Revision: 1.11 $ $Name: not supported by cvs2svn $
+ * @date $Date: 2009-02-06 02:31:24 $
+ *
  * Copyright 2005-2006 Institute for Astronomy, University of Hawaii
  */
@@ -18,19 +19,19 @@
 /// @{
 
+#define PM_HDU_COVARIANCE_KEYWORD "PS_COVAR" // FITS keyword to indicate presence of a covariance matrix
+
 /// An instance of the FITS Header Data Unit
 ///
 /// Of course, it is not an exact replica of a FITS HDU --- they have no mask and weight data, but these are
 /// stored here for convenience --- it keeps all the relevant data about the image in one place.
-typedef struct
-{
+typedef struct {
     psString extname;                   ///< The extension name
     bool blankPHU;                      ///< Is this a blank FITS Primary Header Unit, i.e., no data?
     psMetadata *format;                 ///< The camera format
     psMetadata *header;                 ///< The FITS header, or NULL if primary for FITS; or section info
-    psArray *images;                    ///< The pixel data
-    psArray *weights;                   ///< The pixel data
-    psArray *masks;                     ///< The pixel data
-}
-pmHDU;
+    psArray *images;                    ///< Pixel data
+    psArray *variances;                 ///< Variance in the pixel data, or NULL
+    psArray *masks;                     ///< Mask for the pixel data, or NULL
+} pmHDU;
 
 
@@ -60,9 +61,9 @@
                   );
 
 /// Read the HDU header and weight map
 ///
 /// Moves to the appropriate extension
-bool pmHDUReadWeight(pmHDU *hdu,        ///< HDU to read
-                     psFits *fits       ///< FITS file to read from
+bool pmHDUReadVariance(pmHDU *hdu,        ///< HDU to read
+                       psFits *fits       ///< FITS file to read from
     );
 
@@ -79,8 +80,8 @@
     );
 
-/// Write the HDU header and weight map
-bool pmHDUWriteWeight(pmHDU *hdu,       ///< HDU to write
-                      psFits *fits,     ///< FITS file to write to
-                      const pmConfig *config  ///< Configuration
+/// Write the HDU header and variance map
+bool pmHDUWriteVariance(pmHDU *hdu,       ///< HDU to write
+                        psFits *fits,     ///< FITS file to write to
+                        const pmConfig *config  ///< Configuration
     );
 
@@ -18,19 +19,19 @@
 /// An instance of the FITS Header Data Unit
 ///
-/// Of course, it is not an exact replica of a FITS HDU --- they have no mask and weight data, but these are
+/// Of course, it is not an exact replica of a FITS HDU --- they have no mask and variance data, but these are
 /// stored here for convenience --- it keeps all the relevant data about the image in one place.
@@ -60,9 +61,9 @@
                   );
 
-/// Read the HDU header and weight map
+/// Read the HDU header and variance map
 ///
 /// Moves to the appropriate extension
